db_folder = 'C:/Users/C21252/City of Houston/HWP-AIAP-TEAM - Documents/General/Working/Peng/Peng Work Final/__tracing_database'
datawarehouse = 'C:/Users/C21252/City of Houston/WWIP Planning Data Warehouse - General/GIS Database/01_Infrastructure'
